@@ -96,11 +96,11 @@
 static void query (void);
 static void run   (gchar   *name,
 		   gint     nparams,
-		   GParam  *param,
+		   GimpParam  *param,
 		   gint    *nreturn_vals,
-		   GParam **return_vals);
+		   GimpParam **return_vals);
 
-static void explorer            (GDrawable    *drawable);
+static void explorer            (GimpDrawable    *drawable);
 static void explorer_render_row (const guchar *src_row,
 				 guchar       *dest_row,
 				 gint          row,
@@ -120,9 +120,10 @@ static gint        new_button_press  (GtkWidget *widget,
 				      GdkEventButton *bevent,
 				      gpointer   data);
 
-static gint        delete_fractal_callback              (GtkWidget *widget,
+static void        delete_dialog_callback               (GtkWidget *widget,
+							 gboolean   value,
 						         gpointer   data);
-static gint        delete_button_press_ok               (GtkWidget *widget,
+static gint        delete_fractal_callback              (GtkWidget *widget,
 						         gpointer   data);
 static void        fractalexplorer_list_ok_callback     (GtkWidget *widget,
 						         gpointer   data);
@@ -150,19 +151,14 @@ static void        fractalexplorer_free_everything   (fractalexplorerOBJ *feOBJ)
 static void        fractalexplorer_list_free_all             (void);
 static fractalexplorerOBJ * fractalexplorer_load       (gchar     *filename,
 							gchar     *name);
-static void        fractalexplorer_rescan_file_selection_ok  (GtkWidget *widget,
-							GtkFileSelection *fs,
-							gpointer   data);
 
 static void        fractalexplorer_list_load_all             (GList     *plist);
 static void        fractalexplorer_rescan_ok_callback        (GtkWidget *widget,
-							gpointer   data);
-static void        fractalexplorer_rescan_add_entry_callback (GtkWidget *widget,
-							gpointer   data);
+							      gpointer   data);
 static void        fractalexplorer_rescan_list               (void);
 
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -183,29 +179,29 @@ MAIN()
 static void
 query (void)
 {
-  static GParamDef args[] =
+  static GimpParamDef args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_IMAGE, "image", "Input image" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
-    { PARAM_INT8, "fractaltype", "0: Mandelbrot; 1: Julia; 2: Barnsley 1; 3: Barnsley 2; 4: Barnsley 3; 5: Spider; 6: ManOWar; 7: Lambda; 8: Sierpinski" },
-    { PARAM_FLOAT, "xmin", "xmin fractal image delimiter" },
-    { PARAM_FLOAT, "xmax", "xmax fractal image delimiter" },
-    { PARAM_FLOAT, "ymin", "ymin fractal image delimiter" },
-    { PARAM_FLOAT, "ymax", "ymax fractal image delimiter" },
-    { PARAM_FLOAT, "iter", "Iteration value" },
-    { PARAM_FLOAT, "cx", "cx value ( only Julia)" },
-    { PARAM_FLOAT, "cy", "cy value ( only Julia)" },
-    { PARAM_INT8, "colormode", "0: Apply colormap as specified by the parameters below; 1: Apply active gradient to final image" },
-    { PARAM_FLOAT, "redstretch", "Red stretching factor" },
-    { PARAM_FLOAT, "greenstretch", "Green stretching factor" },
-    { PARAM_FLOAT, "bluestretch", "Blue stretching factor" },
-    { PARAM_INT8, "redmode", "Red application mode (0:SIN;1:COS;2:NONE)" },
-    { PARAM_INT8, "greenmode", "Green application mode (0:SIN;1:COS;2:NONE)" },
-    { PARAM_INT8, "bluemode", "Blue application mode (0:SIN;1:COS;2:NONE)" },
-    { PARAM_INT8, "redinvert", "Red inversion mode (1: enabled; 0: disabled)" },
-    { PARAM_INT8, "greeninvert", "Green inversion mode (1: enabled; 0: disabled)" },
-    { PARAM_INT8, "blueinvert", "Green inversion mode (1: enabled; 0: disabled)" },
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
+    { GIMP_PDB_INT8, "fractaltype", "0: Mandelbrot; 1: Julia; 2: Barnsley 1; 3: Barnsley 2; 4: Barnsley 3; 5: Spider; 6: ManOWar; 7: Lambda; 8: Sierpinski" },
+    { GIMP_PDB_FLOAT, "xmin", "xmin fractal image delimiter" },
+    { GIMP_PDB_FLOAT, "xmax", "xmax fractal image delimiter" },
+    { GIMP_PDB_FLOAT, "ymin", "ymin fractal image delimiter" },
+    { GIMP_PDB_FLOAT, "ymax", "ymax fractal image delimiter" },
+    { GIMP_PDB_FLOAT, "iter", "Iteration value" },
+    { GIMP_PDB_FLOAT, "cx", "cx value ( only Julia)" },
+    { GIMP_PDB_FLOAT, "cy", "cy value ( only Julia)" },
+    { GIMP_PDB_INT8, "colormode", "0: Apply colormap as specified by the parameters below; 1: Apply active gradient to final image" },
+    { GIMP_PDB_FLOAT, "redstretch", "Red stretching factor" },
+    { GIMP_PDB_FLOAT, "greenstretch", "Green stretching factor" },
+    { GIMP_PDB_FLOAT, "bluestretch", "Blue stretching factor" },
+    { GIMP_PDB_INT8, "redmode", "Red application mode (0:SIN;1:COS;2:NONE)" },
+    { GIMP_PDB_INT8, "greenmode", "Green application mode (0:SIN;1:COS;2:NONE)" },
+    { GIMP_PDB_INT8, "bluemode", "Blue application mode (0:SIN;1:COS;2:NONE)" },
+    { GIMP_PDB_INT8, "redinvert", "Red inversion mode (1: enabled; 0: disabled)" },
+    { GIMP_PDB_INT8, "greeninvert", "Green inversion mode (1: enabled; 0: disabled)" },
+    { GIMP_PDB_INT8, "blueinvert", "Green inversion mode (1: enabled; 0: disabled)" },
   };
   static gint nargs = sizeof(args) / sizeof(args[0]);
 
@@ -219,7 +215,7 @@ query (void)
 			  "December, 1998",
 			  N_("<Image>/Filters/Render/Pattern/Fractal Explorer..."),
 			  "RGB*",
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nargs, 0,
 			  args, NULL);
 }
@@ -231,22 +227,22 @@ query (void)
 static void
 run (gchar   *name,
      gint     nparams,
-     GParam  *param,
+     GimpParam  *param,
      gint    *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  static GParam values[1];
+  static GimpParam values[1];
   gint32        image_ID;
-  GRunModeType  run_mode;
+  GimpRunModeType  run_mode;
   gdouble       xhsiz;
   gdouble       yhsiz;
   gint          pwidth;
   gint          pheight;
-  GStatusType   status = STATUS_SUCCESS;
+  GimpPDBStatusType   status = GIMP_PDB_SUCCESS;
 
   run_mode = param[0].data.d_int32;
 
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
 
   *nreturn_vals = 1;
@@ -293,7 +289,7 @@ run (gchar   *name,
   /* See how we will run */
   switch (run_mode)
     {
-    case RUN_INTERACTIVE:
+    case GIMP_RUN_INTERACTIVE:
       /* Possibly retrieve data */
       gimp_get_data ("plug_in_fractalexplorer", &wvals);
 
@@ -303,11 +299,11 @@ run (gchar   *name,
 
       break;
 
-    case RUN_NONINTERACTIVE:
+    case GIMP_RUN_NONINTERACTIVE:
       /* Make sure all the arguments are present */
       if (nparams != 22)
 	{
-	  status = STATUS_CALLING_ERROR;
+	  status = GIMP_PDB_CALLING_ERROR;
 	}
       else
 	{
@@ -334,7 +330,7 @@ run (gchar   *name,
       make_color_map();
       break;
 
-    case RUN_WITH_LAST_VALS:
+    case GIMP_RUN_WITH_LAST_VALS:
       /* Possibly retrieve data */
       gimp_get_data ("plug_in_fractalexplorer", &wvals);
       make_color_map ();
@@ -351,7 +347,7 @@ run (gchar   *name,
   cx = wvals.cx;
   cy = wvals.cy;
 
-  if (status == STATUS_SUCCESS)
+  if (status == GIMP_PDB_SUCCESS)
     {
       /*  Make sure that the drawable is indexed or RGB color  */
       if (gimp_drawable_is_rgb(drawable->id))
@@ -363,17 +359,17 @@ run (gchar   *name,
 	  /* Run! */
 
 	  explorer (drawable);
-	  if (run_mode != RUN_NONINTERACTIVE)
+	  if (run_mode != GIMP_RUN_NONINTERACTIVE)
 	    gimp_displays_flush ();
 
 	  /* Store data */
-	  if (run_mode == RUN_INTERACTIVE)
+	  if (run_mode == GIMP_RUN_INTERACTIVE)
 	    gimp_set_data ("plug_in_fractalexplorer",
 			   &wvals, sizeof (explorer_vals_t));
 	}
       else
 	{
-	  status = STATUS_EXECUTION_ERROR;
+	  status = GIMP_PDB_EXECUTION_ERROR;
 	}
     }
   values[0].data.d_status = status;
@@ -386,10 +382,10 @@ run (gchar   *name,
  *********************************************************************/
 
 static void
-explorer (GDrawable * drawable)
+explorer (GimpDrawable * drawable)
 {
-  GPixelRgn   srcPR;
-  GPixelRgn   destPR;
+  GimpPixelRgn   srcPR;
+  GimpPixelRgn   destPR;
   gint        width;
   gint        height;
   gint        bytes;
@@ -648,86 +644,109 @@ explorer_render_row (const guchar *src_row,
     }
 }
 
-static gint
-delete_button_press_cancel (GtkWidget *widget,
-			    gpointer   data)
+static void
+delete_dialog_callback (GtkWidget *widget,
+			gboolean   delete,
+			gpointer   data)
 {
-  gtk_widget_destroy (delete_dialog);
-  gtk_widget_set_sensitive (delete_frame_to_freeze, TRUE);
-  delete_dialog = NULL;
+  gint       pos;
+  GList     *sellist;
+  fractalexplorerOBJ *sel_obj;
+  GtkWidget *list = (GtkWidget *) data;
 
-  return FALSE;
+  if (delete)
+    {
+      /* Must update which object we are editing */
+      /* Get the list and which item is selected */
+      /* Only allow single selections */
+
+      sellist = GTK_LIST(list)->selection; 
+      
+      /* g_print ("list: %i\n", g_list_length (sellist)); */
+      
+      sel_obj = (fractalexplorerOBJ *)
+	gtk_object_get_user_data (GTK_OBJECT(sellist->data));
+
+      pos = gtk_list_child_position (GTK_LIST (fractalexplorer_gtk_list),
+				     sellist->data);
+
+      /* Delete the current  item + asssociated file */
+      gtk_list_clear_items (GTK_LIST (fractalexplorer_gtk_list), pos, pos + 1);
+      /* Shadow copy for ordering info */
+      fractalexplorer_list = g_list_remove (fractalexplorer_list, sel_obj);
+      /*
+	if(sel_obj == current_obj)
+	{
+	clear_undo();
+	}
+      */  
+      /* Free current obj */
+      fractalexplorer_free_everything (sel_obj);
+
+      /* Select previous one */
+      if (pos > 0)
+	pos--;
+      
+      if ((pos == 0) && (g_list_length (fractalexplorer_list) == 0))
+	{
+	  /*gtk_widget_sed_sensitive ();*/
+	  /* Warning - we have a problem here
+	   * since we are not really "creating an entry"
+	   * why call fractalexplorer_new?
+	   */
+	  new_button_press(NULL,NULL,NULL);
+	}
+
+      gtk_widget_set_sensitive (delete_frame_to_freeze, TRUE);
+
+      gtk_list_select_item (GTK_LIST (fractalexplorer_gtk_list), pos);
+
+      current_obj = g_list_nth_data (fractalexplorer_list, pos);
+
+      list_button_update(current_obj);
+    }
+  else
+    {
+      gtk_widget_set_sensitive (delete_frame_to_freeze, TRUE);
+    }
+
+  delete_dialog = NULL;
+  
+  return;
 }
 
 static gint
 delete_fractal_callback (GtkWidget *widget,
 			 gpointer   data)
 {
-  GtkWidget *vbox;
-  GtkWidget *label;
-  GtkWidget *button;
-  char      *str;
-  GtkWidget *list = (GtkWidget *)data;
-  GList * sellist;
+  gchar     *str;
+  GtkWidget *list = (GtkWidget *) data;
+  GList     *sellist;
   fractalexplorerOBJ * sel_obj;
 
+  if (delete_dialog)
+    return FALSE;
+
   sellist = GTK_LIST(list)->selection; 
 
-  sel_obj = (fractalexplorerOBJ *)gtk_object_get_user_data(GTK_OBJECT((GtkWidget *)(sellist->data)));
-  if(delete_dialog)
-    return(FALSE);
+  sel_obj = (fractalexplorerOBJ *)
+    gtk_object_get_user_data (GTK_OBJECT ((GtkWidget *) (sellist->data)));
 
-  delete_dialog = gtk_dialog_new ();
-  gtk_window_set_title(GTK_WINDOW(delete_dialog), _("Delete fractal"));
-  gtk_window_position(GTK_WINDOW(delete_dialog), GTK_WIN_POS_MOUSE);
-  gtk_container_set_border_width(GTK_CONTAINER(delete_dialog), 0);
-  
-  vbox = gtk_vbox_new(FALSE, 0);
-  gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(delete_dialog)->vbox), vbox,
-		     FALSE, FALSE, 0);
-  gtk_widget_show(vbox);
-  
-  /* Question */
-  
-  label = gtk_label_new(_("Are you sure you want to delete"));
-  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
-  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-  gtk_widget_show(label);
-  
-  str = g_strdup_printf (_("\"%s\" from the list and from disk?"), 
+  str = g_strdup_printf (_("Are you sure you want to delete\n"
+			   "\"%s\" from the list and from disk?"), 
 			 sel_obj->draw_name);
   
-  label = gtk_label_new(str);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
-  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-  gtk_widget_show(label);
-  
-  g_free(str);
-  
-  /* Buttons */
-  button = gtk_button_new_with_label (_("Delete"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      (GtkSignalFunc) delete_button_press_ok,
-                      data);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (delete_dialog)->action_area), button, TRUE, TRUE, 0);
-  gtk_widget_grab_default (button);
-  gtk_object_set_user_data(GTK_OBJECT(button),widget);
-  gtk_widget_show (button);
-  
-  button = gtk_button_new_with_label (_("Cancel"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      (GtkSignalFunc) delete_button_press_cancel,
-                      data);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (delete_dialog)->action_area), button, TRUE, TRUE, 0);
-  gtk_widget_grab_default (button);
-  gtk_object_set_user_data(GTK_OBJECT(button),widget);
-  gtk_widget_show (button);
-  
-  /* Show! */
-  
+  delete_dialog = gimp_query_boolean_box (_("Delete Fractal"),
+					  gimp_standard_help_func, 
+					  "filters/fractalexplorer.html", 
+					  FALSE,
+					  str, 
+					  _("Delete"), _("Cancel"),
+					  GTK_OBJECT (widget), "destroy",
+					  delete_dialog_callback,
+					  data);
+  g_free (str);
+
   gtk_widget_set_sensitive (GTK_WIDGET (delete_frame_to_freeze), FALSE);
   gtk_widget_show (delete_dialog);
 
@@ -781,7 +800,7 @@ fractalexplorer_list_cancel_callback (GtkWidget *widget,
       /* We are creating an entry so if cancelled
        * must del the list item as well
        */
-      delete_button_press_ok (widget, fractalexplorer_gtk_list);
+      delete_dialog_callback (widget, TRUE, fractalexplorer_gtk_list);
     }
 
   gtk_widget_destroy (options->query_box);
@@ -808,7 +827,7 @@ fractalexplorer_dialog_edit_list (GtkWidget          *lwidget,
   /*  the dialog  */
   options->query_box = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (options->query_box), _("Edit fractal name"));
-  gtk_window_position (GTK_WINDOW (options->query_box), GTK_WIN_POS_MOUSE);
+  gtk_window_set_position (GTK_WINDOW (options->query_box), GTK_WIN_POS_MOUSE);
 
   /*  the main vbox  */
   vbox = gtk_vbox_new (FALSE, 1);
@@ -1114,82 +1133,54 @@ list_button_press (GtkWidget      *widget,
 void
 plug_in_parse_fractalexplorer_path (void)
 {
-  GParam *return_vals;
-  gint nreturn_vals;
-  gchar *path_string;
-  gchar *home;
-  gchar *path;
-  gchar *token;
-  gchar *next_token;
-  struct stat filestat;
-  gint	err;
-  
-  if(fractalexplorer_path_list)
-    g_list_free(fractalexplorer_path_list);
-  
+  GList *fail_list = NULL;
+  GList *list;
+  gchar *fractalexplorer_path;
+
+  gimp_path_free (fractalexplorer_path_list);
   fractalexplorer_path_list = NULL;
+
+  fractalexplorer_path = gimp_gimprc_query ("fractalexplorer-path");
   
-  return_vals = gimp_run_procedure ("gimp_gimprc_query",
-				    &nreturn_vals,
-				    PARAM_STRING, "fractalexplorer-path",
-				    PARAM_END);
-  
-  if (return_vals[0].data.d_status != STATUS_SUCCESS ||
-      return_vals[1].data.d_string == NULL)
+  if (!fractalexplorer_path)
     {
+      gchar *gimprc = gimp_personal_rc_file ("gimprc");
+      gchar *path = gimp_strescape
+	("${gimp_dir}" G_DIR_SEPARATOR_S "fractalexplorer"
+	 G_SEARCHPATH_SEPARATOR_S
+	 "${gimp_data_dir}" G_DIR_SEPARATOR_S "fractalexplorer",
+	 NULL);
       g_message (_("No fractalexplorer-path in gimprc:\n"
 		   "You need to add an entry like\n"
-		   "(fractalexplorer-path \"${gimp_dir}/fractalexplorer:${gimp_data_dir}/fractalexplorer\")\n"
-		   "to your ~/.gimp-1.1/gimprc file\n"));
-      gimp_destroy_params (return_vals, nreturn_vals);
+		   "(fractalexplorer-path \"%s\")\n"
+		   "to your %s file."), path, gimprc);
+      g_free (gimprc);
+      g_free (path);
       return;
     }
 
-  path_string = g_strdup (return_vals[1].data.d_string);
-  gimp_destroy_params (return_vals, nreturn_vals);
+  fractalexplorer_path_list = gimp_path_parse (fractalexplorer_path,
+					       16, TRUE, &fail_list);
 
-  /* Set local path to contain temp_path, where (supposedly)
-   * there may be working files.
-   */
-  home = g_get_home_dir ();
+  g_free (fractalexplorer_path);
 
-  /* Search through all directories in the  path */
-
-  next_token = path_string;
-  token = strtok (next_token, G_SEARCHPATH_SEPARATOR_S);
-
-  while (token)
+  if (fail_list)
     {
-      if (*token == '\0')
-	{
-	  token = strtok (NULL, G_SEARCHPATH_SEPARATOR_S);
-	  continue;
-	}
+      GString *err =
+        g_string_new (_("fractalexplorer-path misconfigured - "
+                        "the following directories were not found"));
 
-      if (*token == '~')
-	{
-	  path = g_strdup_printf ("%s%s", home, token + 1);
-	}
-      else
-	{
-	  path = g_strdup (token);
-	} /* else */
+      for (list = fail_list; list; list = g_list_next (list))
+        {
+          g_string_append_c (err, '\n');
+          g_string_append (err, (gchar *) list->data);
+        }
 
-      /* Check if directory exists */
-      err = stat (path, &filestat);
+      g_message (err->str);
 
-      if (!err && S_ISDIR (filestat.st_mode))
-	{
-	  fractalexplorer_path_list = g_list_append (fractalexplorer_path_list, path);
-	}
-      else
-	{
-	  g_message (_("fractalexplorer-path miss-configured - \nPath `%.100s' not found\n"), path);
-	  g_free (path);
-	}
-      token = strtok (NULL, G_SEARCHPATH_SEPARATOR_S);
+      g_string_free (err, TRUE);
+      gimp_path_free (fail_list);
     }
-  g_free (path_string);
 }
 
 static void
@@ -1287,38 +1278,6 @@ fractalexplorer_load (gchar *filename,
   return fractalexplorer;
 }
 
-static void
-fractalexplorer_rescan_file_selection_ok (GtkWidget        *widget,
-					  GtkFileSelection *fs,
-					  gpointer          data)
-{
-  GtkWidget *list_item;
-  GtkWidget *lw = (GtkWidget *) gtk_object_get_user_data (GTK_OBJECT (fs));
-  gchar * filenamebuf;
-  struct stat	filestat;
-  gint		err;
-
-  filenamebuf = gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs));
-
-  err = stat(filenamebuf, &filestat);
-
-  if (!S_ISDIR (filestat.st_mode))
-    {
-      g_warning("Entry %.100s is not a directory\n", filenamebuf);
-    }  
-  else
-    {
-      list_item = gtk_list_item_new_with_label (filenamebuf);
-      gtk_widget_show (list_item);
-
-      gtk_list_prepend_items (GTK_LIST (lw), g_list_append (NULL, list_item));
-
-      rescan_list = g_list_prepend (rescan_list, g_strdup (filenamebuf));
-    }
-
-  gtk_widget_destroy (GTK_WIDGET (fs));
-}
-
 static void
 fractalexplorer_list_load_all (GList *plist)
 {
@@ -1459,212 +1418,76 @@ static void
 fractalexplorer_rescan_ok_callback (GtkWidget *widget,
 				    gpointer   data)
 {
-  GList *list;
+  GtkWidget *patheditor;
+  gchar     *raw_path;
 
-  list = rescan_list;
-  while (list)
+  gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
+
+  gimp_path_free (fractalexplorer_path_list);
+  fractalexplorer_path_list = NULL;
+
+  patheditor = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (data),
+                                                "patheditor"));
+
+  raw_path = gimp_path_editor_get_path (GIMP_PATH_EDITOR (patheditor));
+
+  fractalexplorer_path_list = gimp_path_parse (raw_path, 16, FALSE, NULL);
+
+  g_free (raw_path);
+
+  if (fractalexplorer_path_list)
     {
-      list = list->next;
-    }
-  list = fractalexplorer_path_list;
-  while (list) 
-    {
-      rescan_list = g_list_append (rescan_list, g_strdup (list->data));
-      list = list->next;
+      gtk_list_clear_items (GTK_LIST (fractalexplorer_gtk_list), 0, -1);
+      fractalexplorer_list_load_all (fractalexplorer_path_list);
+      build_list_items (fractalexplorer_gtk_list);
+      list_button_update (current_obj);
     }
 
-  gtk_list_clear_items (GTK_LIST (fractalexplorer_gtk_list), 0, -1);
-  fractalexplorer_list_load_all (rescan_list);
-  build_list_items (fractalexplorer_gtk_list);
-  list_button_update (current_obj);
   gtk_widget_destroy (GTK_WIDGET (data));
 }
 
-static void
-fractalexplorer_rescan_add_entry_callback (GtkWidget *widget,
-					   gpointer   data)
-{
-  static GtkWidget *window = NULL;
-
-  /* Call up the file sel dialogue */
-  window = gtk_file_selection_new (_("Add FractalExplorer path"));
-  gtk_window_position (GTK_WINDOW (window), GTK_WIN_POS_MOUSE);
-  gtk_object_set_user_data (GTK_OBJECT (window), data);
-
-  gtk_signal_connect (GTK_OBJECT (window), "destroy",
-		      GTK_SIGNAL_FUNC (gtk_widget_destroyed),
-		      &window);
-
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (window)->ok_button),
-		      "clicked",
-		      GTK_SIGNAL_FUNC (fractalexplorer_rescan_file_selection_ok),
-		      window);
-
-  gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (window)->cancel_button),
-			     "clicked",
-			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (window));
-
-  gtk_widget_show (window);
-}
-
 static void
 fractalexplorer_rescan_list (void)
 {
-  GtkWidget *vbox;
-  GtkWidget *button;
-  GtkWidget *dlg;
-  GtkWidget *list_frame;
-  GtkWidget *scrolled_win;
-  GtkWidget *list_widget;
-  GList *list;
+  static GtkWidget *dlg = NULL;
+
+  GtkWidget *patheditor;
+  gchar     *path;
+
+  if (dlg)
+    {
+      gdk_window_raise (dlg->window);
+      return;
+    }
 
   /*  the dialog  */
-  dlg = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dlg), _("Rescan for fractals"));
-  gtk_window_position (GTK_WINDOW (dlg), GTK_WIN_POS_MOUSE);
+  dlg = gimp_dialog_new (_("Rescan for Fractals"), "fractalexplorer",
+                         gimp_standard_help_func, "filters/fractalexplorer.html",
+                         GTK_WIN_POS_MOUSE,
+                         FALSE, TRUE, FALSE,
 
-  /*  the main vbox  */
-  vbox = gtk_vbox_new (FALSE, 1);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), vbox, TRUE, TRUE, 0);
+                         _("OK"), fractalexplorer_rescan_ok_callback,
+                         NULL, NULL, NULL, TRUE, FALSE,
+                         _("Cancel"), gtk_widget_destroy,
+                         NULL, 1, NULL, FALSE, TRUE,
 
-  /* path list */
-  list_frame = gtk_frame_new(NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (list_frame), GTK_SHADOW_ETCHED_IN);
-  gtk_widget_show(list_frame);
+                         NULL);
 
-  scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
-                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_container_add (GTK_CONTAINER (list_frame), scrolled_win);
-  gtk_widget_show (scrolled_win);
+  gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
+                      GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+                      &dlg);
 
-  list_widget = gtk_list_new ();
-  gtk_list_set_selection_mode (GTK_LIST (list_widget), GTK_SELECTION_BROWSE);
-  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled_win),
-					 list_widget);
-  gtk_widget_show (list_widget);
-  gtk_box_pack_start (GTK_BOX (vbox), list_frame, TRUE, TRUE, 0);
+  path = gimp_path_to_str (fractalexplorer_path_list);
 
-  list = fractalexplorer_path_list;
-  while (list)
-    {
-      GtkWidget *list_item;
-      list_item = gtk_list_item_new_with_label(list->data);
-      gtk_widget_show(list_item);
-      gtk_container_add (GTK_CONTAINER (list_widget), list_item);
-      list = list->next;
-    }
+  patheditor = gimp_path_editor_new (_("Add FractalExplorer Path"), path);
+  gtk_container_set_border_width (GTK_CONTAINER (patheditor), 6);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), patheditor,
+                      TRUE, TRUE, 0);
+  gtk_widget_show (patheditor);
 
-  button = gtk_button_new_with_label (_("OK"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      (GtkSignalFunc)fractalexplorer_rescan_ok_callback,
-                      (gpointer)dlg);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->action_area), button, TRUE, TRUE, 0);
-  gtk_widget_grab_default (button);
-  gtk_widget_show (button);
+  g_free (path);
 
-  /* Clear the old list out */
-  if((list = rescan_list))
-    {
-      while (list) 
-	{
-	  g_free(list->data);
-	  list = list->next;
-	}
+  gtk_object_set_data (GTK_OBJECT (dlg), "patheditor", patheditor);
 
-      g_list_free(rescan_list);
-      rescan_list = NULL;
-    }
-
-  button = gtk_button_new_with_label (_("Add dir"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      (GtkSignalFunc)fractalexplorer_rescan_add_entry_callback,
-                      (gpointer)list_widget);
-
-  gtk_object_set_user_data(GTK_OBJECT(dlg),(gpointer)list_widget);
-
-
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->action_area), button, TRUE, TRUE, 0);
-  gtk_widget_show (button);
-
-  button = gtk_button_new_with_label (_("Cancel"));
-  gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
-			     GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (dlg));
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->action_area), button, TRUE, TRUE, 0);
-  gtk_widget_show (button);
-
-  gtk_widget_show (vbox);
   gtk_widget_show (dlg);
 }
-
-static gint
-delete_button_press_ok(GtkWidget *widget,
-		       gpointer   data)
-{
-  gint pos;
-  GList * sellist;
-  fractalexplorerOBJ * sel_obj;
-  GtkWidget *list = (GtkWidget *)data;
-
-  /* Must update which object we are editing */
-  /* Get the list and which item is selected */
-  /* Only allow single selections */
-
-  sellist = GTK_LIST(list)->selection; 
-
-  g_print ("list: %i\n", g_list_length (sellist));
-
-  sel_obj = (fractalexplorerOBJ *)gtk_object_get_user_data(GTK_OBJECT((GtkWidget *)(sellist->data)));
-
-  pos = gtk_list_child_position(GTK_LIST(fractalexplorer_gtk_list),sellist->data);
-
-  /* Delete the current  item + asssociated file */
-  gtk_list_clear_items(GTK_LIST (fractalexplorer_gtk_list),pos,pos+1);
-  /* Shadow copy for ordering info */
-  fractalexplorer_list = g_list_remove(fractalexplorer_list,sel_obj);
-/*
-  if(sel_obj == current_obj)
-    {
-      clear_undo();
-    }
-*/  
-  /* Free current obj */
-  fractalexplorer_free_everything(sel_obj);
-
-  /* Select previous one */
-  if (pos > 0)
-    pos--;
-
-  if((pos == 0) && (g_list_length(fractalexplorer_list) == 0))
-    {      
-      /* Warning - we have a problem here
-       * since we are not really "creating an entry"
-       * why call fractalexplorer_new?
-       */
-      new_button_press(NULL,NULL,NULL);
-    }
-
-  gtk_widget_destroy(delete_dialog);
-  gtk_widget_set_sensitive(delete_frame_to_freeze,TRUE);
-
-  delete_dialog = NULL;
-
-  gtk_list_select_item(GTK_LIST(fractalexplorer_gtk_list), pos);
-
-  current_obj = g_list_nth_data(fractalexplorer_list,pos);
-
-  /*
-  draw xxxxxxxxxxxxxxxx 
-  update_draw_area(fractalexplorer_preview,NULL);
-  */
-
-  list_button_update(current_obj);
-
-  return FALSE;
-}
