@@ -128,11 +128,11 @@ static BlurInterface blur_int =
 static void query (void);
 static void run   (gchar   *name,
 		   gint     nparams,
-		   GParam  *param,
+		   GimpParam  *param,
 		   gint    *nreturn_vals,
-		   GParam **return_vals);
+		   GimpParam **return_vals);
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -140,9 +140,9 @@ GPlugInInfo PLUG_IN_INFO =
   run,   /* run_proc   */
 };
 
-static void blur (GDrawable *drawable);
+static void blur (GimpDrawable *drawable);
 
-static inline void blur_prepare_row (GPixelRgn *pixel_rgn,
+static inline void blur_prepare_row (GimpPixelRgn *pixel_rgn,
 				     guchar    *data,
 				     gint       x,
 				     gint       y,
@@ -167,23 +167,23 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef args_ni[] =
+  static GimpParamDef args_ni[] =
   {
-    { PARAM_INT32, "run_mode", "non-interactive" },
-    { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" }
+    { GIMP_PDB_INT32, "run_mode", "non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image (unused)" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" }
   };
   static gint nargs_ni = sizeof(args_ni) / sizeof (args_ni[0]);
 
-  static GParamDef args[] =
+  static GimpParamDef args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
-    { PARAM_FLOAT, "blur_pct", "Randomization percentage (1 - 100)" },
-    { PARAM_FLOAT, "blur_rcount", "Repeat count(1 - 100)" },
-    { PARAM_INT32, "seed_type", "Seed type (10 = current time, 11 = seed value)" },
-    { PARAM_INT32, "blur_seed", "Seed value (used only if seed type is 11)" }
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image (unused)" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
+    { GIMP_PDB_FLOAT, "blur_pct", "Randomization percentage (1 - 100)" },
+    { GIMP_PDB_FLOAT, "blur_rcount", "Repeat count(1 - 100)" },
+    { GIMP_PDB_INT32, "seed_type", "Seed type (10 = current time, 11 = seed value)" },
+    { GIMP_PDB_INT32, "blur_seed", "Seed value (used only if seed type is 11)" }
   };
   static gint nargs = sizeof(args) / sizeof (args[0]);
 
@@ -201,7 +201,7 @@ query (void)
 			  (gchar *) copyright_date,
 			  N_("<Image>/Filters/Blur/Blur..."),
 			  "RGB*, GRAY*",
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nargs, 0,
 			  args, NULL);
 
@@ -213,7 +213,7 @@ query (void)
 			  (gchar *) copyright_date,
 			  NULL,
 			  "RGB*, GRAY*",
-			  PROC_PLUG_IN,
+			  GIMP_PLUGIN,
 			  nargs_ni, 0,
 			  args_ni, NULL);
 }
@@ -230,15 +230,15 @@ query (void)
 static void
 run (gchar   *name, 
      gint     nparams, 
-     GParam  *param, 
+     GimpParam  *param, 
      gint    *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  GDrawable *drawable;
-  GRunModeType run_mode;
-  GStatusType status = STATUS_SUCCESS;        /* assume the best! */
+  GimpDrawable *drawable;
+  GimpRunModeType run_mode;
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;        /* assume the best! */
   gchar prog_label[32];
-  static GParam values[1];
+  static GimpParam values[1];
 
   INIT_I18N_UI();
 
@@ -248,7 +248,7 @@ run (gchar   *name,
   run_mode = param[0].data.d_int32;
   drawable = gimp_drawable_get(param[2].data.d_drawable);
 
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
   *nreturn_vals = 1;
   *return_vals = values;
@@ -263,7 +263,7 @@ run (gchar   *name,
 	  /*
 	   *  If we're running interactively, pop up the dialog box.
 	   */
-	case RUN_INTERACTIVE:
+	case GIMP_RUN_INTERACTIVE:
 	  gimp_get_data (PLUG_IN_NAME, &pivals);
 	  if (!blur_dialog ())        /* return on Cancel */
 	    return;
@@ -275,7 +275,7 @@ run (gchar   *name,
 	   *  we don't use the dialog box.  Make sure all
 	   *  parameters have legitimate values.
 	   */
-	case RUN_NONINTERACTIVE:
+	case GIMP_RUN_NONINTERACTIVE:
 	  if ((strcmp (name, "plug_in_blur_randomize") == 0) &&
 	      (nparams == 7))
 	    {
@@ -300,14 +300,14 @@ run (gchar   *name,
 	    }
 	  else
 	    {
-	      status = STATUS_CALLING_ERROR;
+	      status = GIMP_PDB_CALLING_ERROR;
 	    }
 	  break;
 
 	  /*
 	   *  If we're running with the last set of values, get those values.
 	   */
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  gimp_get_data (PLUG_IN_NAME, &pivals);
 	  break;
 
@@ -318,7 +318,7 @@ run (gchar   *name,
 	  break;
         }
 
-      if (status == STATUS_SUCCESS)
+      if (status == GIMP_PDB_SUCCESS)
 	{
 	  /*
 	   *  JUST DO IT!
@@ -338,14 +338,14 @@ run (gchar   *name,
 	  /*
 	   *  If we ran interactively (even repeating) update the display.
 	   */
-	  if (run_mode != RUN_NONINTERACTIVE)
+	  if (run_mode != GIMP_RUN_NONINTERACTIVE)
 	    {
 	      gimp_displays_flush ();
             }
 	  /*
 	   *  If we use the dialog popup, set the data for future use.
 	   */
-	  if (run_mode == RUN_INTERACTIVE)
+	  if (run_mode == GIMP_RUN_INTERACTIVE)
 	    {
 	      gimp_set_data (PLUG_IN_NAME, &pivals, sizeof (BlurVals));
             }
@@ -356,7 +356,7 @@ run (gchar   *name,
       /*
        *  If we got the wrong drawable type, we need to complain.
        */
-      status = STATUS_EXECUTION_ERROR;
+      status = GIMP_PDB_EXECUTION_ERROR;
     }
   /*
    *  DONE!
@@ -377,7 +377,7 @@ run (gchar   *name,
  ********************************/
 
 static inline void
-blur_prepare_row (GPixelRgn *pixel_rgn, 
+blur_prepare_row (GimpPixelRgn *pixel_rgn, 
 		  guchar    *data, 
 		  int        x, 
 		  int        y, 
@@ -416,9 +416,9 @@ blur_prepare_row (GPixelRgn *pixel_rgn,
  ********************************/
 
 static void
-blur (GDrawable *drawable)
+blur (GimpDrawable *drawable)
 {
-  GPixelRgn srcPR, destPR, destPR2, *sp, *dp, *tp;
+  GimpPixelRgn srcPR, destPR, destPR2, *sp, *dp, *tp;
   gint width, height;
   gint bytes;
   guchar *dest, *d;
