@@ -6,8 +6,6 @@ use File::Basename;
 
 require Exporter;
 
-=cut
-
 =head1 NAME
 
 Gimp::Fu - "easy to use" framework for Gimp scripts
@@ -49,35 +47,32 @@ In general, a Gimp::Fu script looks like this:
 C<examples/example-fu.pl>, which is small Gimp::Fu-script you can take as
 starting point for your experiments)
 
-B<Attention:> at the moment it's neccessary to always import the C<Gimp::Fu>
-module after the C<Gimp> module.
-
 =cut
 
-sub PF_INT8	() { Gimp::PARAM_INT8	};
-sub PF_INT16	() { Gimp::PARAM_INT16	};
-sub PF_INT32	() { Gimp::PARAM_INT32	};
-sub PF_FLOAT	() { Gimp::PARAM_FLOAT	};
-sub PF_STRING	() { Gimp::PARAM_STRING	};
-sub PF_COLOR	() { Gimp::PARAM_COLOR	};
-sub PF_COLOUR	() { Gimp::PARAM_COLOR	};
-sub PF_IMAGE	() { Gimp::PARAM_IMAGE	};
-sub PF_LAYER	() { Gimp::PARAM_LAYER	};
-sub PF_CHANNEL	() { Gimp::PARAM_CHANNEL};
-sub PF_DRAWABLE	() { Gimp::PARAM_DRAWABLE};
+sub PF_INT8	() { Gimp::PDB_INT8	};
+sub PF_INT16	() { Gimp::PDB_INT16	};
+sub PF_INT32	() { Gimp::PDB_INT32	};
+sub PF_FLOAT	() { Gimp::PDB_FLOAT	};
+sub PF_STRING	() { Gimp::PDB_STRING	};
+sub PF_COLOR	() { Gimp::PDB_COLOR	};
+sub PF_COLOUR	() { Gimp::PDB_COLOR	};
+sub PF_IMAGE	() { Gimp::PDB_IMAGE	};
+sub PF_LAYER	() { Gimp::PDB_LAYER	};
+sub PF_CHANNEL	() { Gimp::PDB_CHANNEL	};
+sub PF_DRAWABLE	() { Gimp::PDB_DRAWABLE	};
 
-sub PF_TOGGLE	() { Gimp::PARAM_END+1	};
-sub PF_SLIDER	() { Gimp::PARAM_END+2	};
-sub PF_FONT	() { Gimp::PARAM_END+3	};
-sub PF_SPINNER	() { Gimp::PARAM_END+4	};
-sub PF_ADJUSTMENT(){ Gimp::PARAM_END+5	}; # compatibility fix for script-fu _ONLY_
-sub PF_BRUSH	() { Gimp::PARAM_END+6	};
-sub PF_PATTERN	() { Gimp::PARAM_END+7	};
-sub PF_GRADIENT	() { Gimp::PARAM_END+8	};
-sub PF_RADIO	() { Gimp::PARAM_END+9	};
-sub PF_CUSTOM	() { Gimp::PARAM_END+10	};
-sub PF_FILE	() { Gimp::PARAM_END+11	};
-sub PF_TEXT	() { Gimp::PARAM_END+12	};
+sub PF_TOGGLE	() { Gimp::PDB_END+1	};
+sub PF_SLIDER	() { Gimp::PDB_END+2	};
+sub PF_FONT	() { Gimp::PDB_END+3	};
+sub PF_SPINNER	() { Gimp::PDB_END+4	};
+sub PF_ADJUSTMENT(){ Gimp::PDB_END+5	}; # compatibility fix for script-fu _ONLY_
+sub PF_BRUSH	() { Gimp::PDB_END+6	};
+sub PF_PATTERN	() { Gimp::PDB_END+7	};
+sub PF_GRADIENT	() { Gimp::PDB_END+8	};
+sub PF_RADIO	() { Gimp::PDB_END+9	};
+sub PF_CUSTOM	() { Gimp::PDB_END+10	};
+sub PF_FILE	() { Gimp::PDB_END+11	};
+sub PF_TEXT	() { Gimp::PDB_END+12	};
 
 sub PF_BOOL	() { PF_TOGGLE		};
 sub PF_INT	() { PF_INT32		};
@@ -138,17 +133,17 @@ sub carp {
 }
 
 # Some Standard Arguments
-my @image_params = ([&Gimp::PARAM_IMAGE		, "image",	"The image to work on"],
-                    [&Gimp::PARAM_DRAWABLE	, "drawable",	"The drawable to work on"]);
+my @image_params = ([&Gimp::PDB_IMAGE		, "image",	"The image to work on"],
+                    [&Gimp::PDB_DRAWABLE	, "drawable",	"The drawable to work on"]);
 
-my @load_params  = ([&Gimp::PARAM_STRING	, "filename",	"The name of the file"],
-                    [&Gimp::PARAM_STRING	, "raw_filename","The name of the file"]);
+my @load_params  = ([&Gimp::PDB_STRING	, "filename",	"The name of the file"],
+                    [&Gimp::PDB_STRING	, "raw_filename","The name of the file"]);
 
 my @save_params  = (@image_params, @load_params);
 
-my @load_retvals = ([&Gimp::PARAM_IMAGE		, "image",	"Output image"]);
+my @load_retvals = ([&Gimp::PDB_IMAGE		, "image",	"Output image"]);
 
-my $image_retval = [&Gimp::PARAM_IMAGE		, "image",	"The resulting image"];
+my $image_retval = [&Gimp::PDB_IMAGE		, "image",	"The resulting image"];
 
 # expand all the pod directives in string (currently they are only removed)
 sub expand_podsections() {
@@ -319,11 +314,12 @@ Gimp::on_query {
    script:
    for(@scripts) {
       my($perl_sub,$function,$blurb,$help,$author,$copyright,$date,
-         $menupath,$imagetypes,$params,$results,$features,$code,$type)=@$_;
+         $menupath,$imagetypes,$params,$results,$features,$code,$type,
+         $defargs)=@$_;
 
       for (@$results) {
          next if ref $_;
-         if ($_ == &Gimp::PARAM_IMAGE) {
+         if ($_ == &Gimp::PDB_IMAGE) {
             $_ = $image_retval;
          }
       }
@@ -335,32 +331,39 @@ Gimp::on_query {
       # guess the datatype. yeah!
       sub datatype(@) {
          for(@_) {
-            return Gimp::PARAM_STRING unless /^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/; # perlfaq4
-            return Gimp::PARAM_FLOAT  unless /^[+-]?\d+$/; # again
+            return Gimp::PDB_STRING unless /^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/; # perlfaq4
+            return Gimp::PDB_FLOAT  unless /^[+-]?\d+$/; # again
          }
-         return Gimp::PARAM_INT32;
+         return Gimp::PDB_INT32;
       }
       sub odd_values(@) {
          my %x = @_; values %x;
       }
 
       for(@$params) {
-         $_->[0]=Gimp::PARAM_INT32	if $_->[0] == PF_TOGGLE;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_FONT;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_BRUSH;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_PATTERN;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_GRADIENT;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_CUSTOM;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_FILE;
-         $_->[0]=Gimp::PARAM_STRING	if $_->[0] == PF_TEXT;
+         $_->[0]=Gimp::PDB_INT32	if $_->[0] == PF_TOGGLE;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_FONT;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_BRUSH;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_PATTERN;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_GRADIENT;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_CUSTOM;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_FILE;
+         $_->[0]=Gimp::PDB_STRING	if $_->[0] == PF_TEXT;
          $_->[0]=datatype(odd_values(@{$_->[4]})) if $_->[0] == PF_RADIO;
          $_->[0]=datatype($_->[3],@{$_->[4]}) if $_->[0] == PF_SLIDER;
          $_->[0]=datatype($_->[3],@{$_->[4]}) if $_->[0] == PF_SPINNER;
          $_->[0]=datatype($_->[3],@{$_->[4]}) if $_->[0] == PF_ADJUSTMENT;
       }
+
+      # Gtk not installed -> do not install menu entry
+      if (@$params > $defargs) {
+         require Gimp::Feature;
+         undef $menupath unless Gimp::Feature::present('gtk');
+      }
+      
       Gimp->gimp_install_procedure($function,$blurb,$help,$author,$copyright,$date,
                                    $menupath,$imagetypes,$type,
-                                   [[Gimp::PARAM_INT32,"run_mode","Interactive, [non-interactive]"],
+                                   [[Gimp::PDB_INT32,"run_mode","Interactive, [non-interactive]"],
                                     @$params],
                                    $results);
 
@@ -616,7 +619,7 @@ sub register($$$$$$$$$;@) {
    no strict 'refs';
    my($function,$blurb,$help,$author,$copyright,$date,
       $menupath,$imagetypes,$params)=splice(@_,0,9);
-   my($results,$features,$code,$type);
+   my($results,$features,$code,$type,$defargs);
 
    $results  = (ref $_[0] eq "ARRAY") ? shift : [];
    $features = (ref $_[0] eq "ARRAY") ? shift : [];
@@ -624,25 +627,28 @@ sub register($$$$$$$$$;@) {
 
    for($menupath) {
       if (/^<Image>\//) {
-         $type = &Gimp::PROC_PLUG_IN;
+         $type = &Gimp::PLUGIN;
          unshift @$params, @image_params;
+         $defargs = @image_params;
       } elsif (/^<Load>\//) {
-         $type = &Gimp::PROC_PLUG_IN;
+         $type = &Gimp::PLUGIN;
          unshift @$params, @load_params;
          unshift @$results, @load_retvals;
+         $defargs = @load_params;
       } elsif (/^<Save>\//) {
-         $type = &Gimp::PROC_PLUG_IN;
+         $type = &Gimp::PLUGIN;
          unshift @$params, @save_params;
+         $defargs = @save_params;
       } elsif (/^<Toolbox>\//) {
-         $type = &Gimp::PROC_EXTENSION;
+         $type = &Gimp::EXTENSION;
+         $defargs = 0;
       } elsif (/^<None>/) {
-         $type = &Gimp::PROC_EXTENSION;
+         $type = &Gimp::EXTENSION;
+         $defargs = 0;
       } else {
          die __"menupath _must_ start with <Image>, <Toolbox>, <Load>, <Save> or <None>!";
       }
    }
-   #$menupath =~ s%^<Toolbox>/Xtns/%__("<Toolbox>/Xtns/")%e;
-   #$menupath =~ s%^<Image>/Filters/%__("<Image>/Filters/")%e;
    undef $menupath if $menupath eq "<None>";#d#
 
    @_==0 or die __"register called with too many or wrong arguments\n";
@@ -766,7 +772,8 @@ sub register($$$$$$$$$;@) {
 
    Gimp::register_callback($function,$perl_sub);
    push(@scripts,[$perl_sub,$function,$blurb,$help,$author,$copyright,$date,
-                  $menupath,$imagetypes,$params,$results,$features,$code,$type]);
+                  $menupath,$imagetypes,$params,$results,$features,$code,$type,
+                  $defargs]);
 }
 
 =cut
@@ -805,7 +812,9 @@ IMAGETYPE is one of GIF, JPG, JPEG, PNM or PNG, options include
 
  options for PNG images
  -Cn	use compression level n
-
+ -E	Do not skip ancillary chunks (default)
+ +E	Skip ancillary chunks
+ 
  options for JPEG images
  -Qn	use quality "n" to save file (JPEG only)
  -S	do not smooth (default)
@@ -834,6 +843,7 @@ sub save_image($$) {
    $loop=0;
    $delay=0;
    $dispose=0;
+   $noextra=0;
 
    $_=$path=~s/^([^:]+):// ? $1 : "";
    $type=uc($1) if $path=~/\.([^.]+)$/;
@@ -841,6 +851,7 @@ sub save_image($$) {
    while($_ ne "") {
       $interlace=$1 eq "+", 	next if s/^([-+])[iI]//;
       $flatten=$1 eq "+", 	next if s/^([-+])[fF]//;
+      $noextra=$1 eq "+",	next if s/^([-+])[eE]//;
       $smooth=$1 eq "+", 	next if s/^([-+])[sS]//;
       $quality=$1*0.01,		next if s/^-[qQ](\d+)//;
       $compress=$1,		next if s/^-[cC](\d+)//;
@@ -866,7 +877,7 @@ sub save_image($$) {
       }
       $layer->file_gif_save($path,$path,$interlace,$loop,$delay,$dispose);
    } elsif ($type eq "PNG") {
-      $layer->file_png_save($path,$path,$interlace,$compress);
+      $layer->file_png_save($path,$path,$interlace,$noextra,$compress);
    } elsif ($type eq "PNM") {
       $layer->file_pnm_save($path,$path,1);
    } else {
