@@ -58,14 +58,14 @@
 
 (script-fu-register
     "script-fu-coffee-stain"
-    "<Image>/Script-Fu/Decor/Coffee Stain..."
-    "foo"
+    _"<Image>/Script-Fu/Decor/Coffee Stain..."
+    "Draws realistic looking coffee stains"
     "Chris Gutteridge"
     "1998, Chris Gutteridge / ECS dept, University of Southampton, England."
     "25th April 1998"
-    "RGBA RGB"
+    "RGB*"
     SF-IMAGE "The Image" 0
     SF-DRAWABLE "The Layer" 0
-    SF-VALUE "Stains" "3"
-    SF-TOGGLE "Darken Only? (better but only for images with alot of white)" TRUE
+    SF-ADJUSTMENT _"Stains" '(3 1 10 1 1 0 0)
+    SF-TOGGLE _"Darken Only\n(Better, but only for Images with alot of White)" TRUE
 )
